ColorWithOpacity
================

.. currentmodule:: pywwt.traits

.. autoclass:: ColorWithOpacity
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ColorWithOpacity.validate

   .. rubric:: Methods Documentation

   .. automethod:: validate
